Index: linux-2.6.24/drivers/i2c/chips/pcf50633.c
===================================================================
--- linux-2.6.24.orig/drivers/i2c/chips/pcf50633.c
+++ linux-2.6.24/drivers/i2c/chips/pcf50633.c
@@ -567,8 +567,26 @@ static void pcf50633_work(struct work_st
 	 */
 	ret = i2c_smbus_read_i2c_block_data(&pcf->client, PCF50633_REG_INT1, 5,
 					    pcfirq);
-	if (ret != 5)
-		DEBUGP("Oh crap PMU IRQ register read failed %d\n", ret);
+	if (ret != 5) {
+		DEBUGP("Oh crap PMU IRQ register read failed -- "
+		       "retrying later %d\n", ret);
+		/*
+		 * this situation can happen during resume, just defer
+		 * handling the interrupt until enough I2C is up we can
+		 * actually talk to the PMU.  We can't just ignore this
+		 * because we are on a falling edge interrupt and our
+		 * PMU interrupt source does not clear until we read these
+		 * interrupt source registers.
+		 */
+		if (!schedule_work(&pcf->work) && !pcf->working)
+			dev_dbg(&pcf->client.dev, "work item may be lost\n");
+
+		/* we don't put the device here, hold it for next time */
+		mutex_unlock(&pcf->working_lock);
+		/* don't spew, delaying whatever else is happening */
+		msleep(1);
+		return;
+	}
 
 	if (!pcf->coldplug_done) {
 		DEBUGP("PMU Coldplug init\n");
